@@ -191,6 +191,7 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\dbend', '☡'),
     ('\\ddag', '‡'),
     ('\\ddots', '⋱'),
+    ('\\ddot{\\phantom{x}}', '̈'),
     ('\\Delta', 'Δ'),
     ('\\delta', 'δ'),
     ('\\diameter', '⌀'),
@@ -220,6 +221,8 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\euro', '€'),
     ('\\exists', '∃'),
     ('\\fallingdotseq', '≒'),
+    ('\\fbox{\\checkmark}', '☑'),
+    ('\\fbox{\\phantom{{\\checkmark}}}', '☐'),
     ('\\Finv', 'Ⅎ'),
     ('\\flat', '♭'),
     ('\\forall', '∀'),
@@ -258,14 +261,17 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\guillemotright', '»'),
     ('\\guilsinglleft', '‹'),
     ('\\guilsinglright', '›'),
+    ('\\hat{\\phantom{x}}', '̂'),
     ('\\hbar', 'ℏ'),
     ('\\heartsuit', '♡'),
+    ('\\hl', ''),
     ('\\hookleftarrow', '↩'),
     ('\\hookrightarrow', '↪'),
     ('\\iddots', '⋰'),
     ('\\iiiint', '⨌'),
     ('\\iiint', '∭'),
     ('\\iint', '∬'),
+    ('\\Im', 'ℑ'),
     ('\\IM', 'ℑ'),
     ('\\imath', 'ı'),
     ('\\in', '∈'),
@@ -394,10 +400,194 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\mathbb{y}', '𝕪'),
     ('\\mathbb{Z}', 'ℤ'),
     ('\\mathbb{z}', '𝕫'),
+    ('\\mathbf{A}', '𝐀'),
+    ('\\mathbf{a}', '𝐚'),
+    ('\\mathbf{B}', '𝐁'),
+    ('\\mathbf{b}', '𝐛'),
+    ('\\mathbf{C}', '𝐂'),
+    ('\\mathbf{c}', '𝐜'),
+    ('\\mathbf{D}', '𝐃'),
+    ('\\mathbf{d}', '𝐝'),
+    ('\\mathbf{E}', '𝐄'),
+    ('\\mathbf{e}', '𝐞'),
+    ('\\mathbf{F}', '𝐅'),
+    ('\\mathbf{f}', '𝐟'),
+    ('\\mathbf{G}', '𝐆'),
+    ('\\mathbf{g}', '𝐠'),
+    ('\\mathbf{H}', '𝐇'),
+    ('\\mathbf{h}', '𝐡'),
+    ('\\mathbf{I}', '𝐈'),
+    ('\\mathbf{i}', '𝐢'),
+    ('\\mathbf{J}', '𝐉'),
+    ('\\mathbf{j}', '𝐣'),
+    ('\\mathbf{K}', '𝐊'),
+    ('\\mathbf{k}', '𝐤'),
+    ('\\mathbf{L}', '𝐋'),
+    ('\\mathbf{l}', '𝐥'),
+    ('\\mathbf{M}', '𝐌'),
+    ('\\mathbf{m}', '𝐦'),
+    ('\\mathbf{N}', '𝐍'),
+    ('\\mathbf{n}', '𝐧'),
+    ('\\mathbf{O}', '𝐎'),
+    ('\\mathbf{o}', '𝐨'),
+    ('\\mathbf{P}', '𝐏'),
+    ('\\mathbf{p}', '𝐩'),
+    ('\\mathbf{Q}', '𝐐'),
+    ('\\mathbf{q}', '𝐪'),
+    ('\\mathbf{R}', '𝐑'),
+    ('\\mathbf{r}', '𝐫'),
+    ('\\mathbf{S}', '𝐒'),
+    ('\\mathbf{s}', '𝐬'),
+    ('\\mathbf{T}', '𝐓'),
+    ('\\mathbf{t}', '𝐭'),
+    ('\\mathbf{U}', '𝐔'),
+    ('\\mathbf{u}', '𝐮'),
+    ('\\mathbf{V}', '𝐕'),
+    ('\\mathbf{v}', '𝐯'),
+    ('\\mathbf{W}', '𝐖'),
+    ('\\mathbf{w}', '𝐰'),
+    ('\\mathbf{X}', '𝐗'),
+    ('\\mathbf{x}', '𝐱'),
+    ('\\mathbf{Y}', '𝐘'),
+    ('\\mathbf{y}', '𝐲'),
+    ('\\mathbf{Z}', '𝐙'),
+    ('\\mathbf{z}', '𝐳'),
+    ('\\mathcal B', 'ℬ'),
+    ('\\mathcal e', 'ℯ'),
+    ('\\mathcal E', 'ℰ'),
+    ('\\mathcal F', 'ℱ'),
     ('\\mathcal g', 'ℊ'),
+    ('\\mathcal H', 'ℋ'),
+    ('\\mathcal I', 'ℐ'),
+    ('\\mathcal L', 'ℒ'),
+    ('\\mathcal{A}', '𝓐'),
+    ('\\mathcal{B}', '𝓑'),
+    ('\\mathcal{C}', '𝓒'),
+    ('\\mathcal{D}', '𝓓'),
+    ('\\mathcal{E}', '𝓔'),
+    ('\\mathcal{F}', '𝓕'),
+    ('\\mathcal{G}', '𝓖'),
+    ('\\mathcal{H}', '𝓗'),
+    ('\\mathcal{I}', '𝓘'),
+    ('\\mathcal{J}', '𝓙'),
+    ('\\mathcal{K}', '𝓚'),
+    ('\\mathcal{L}', '𝓛'),
+    ('\\mathcal{M}', '𝓜'),
+    ('\\mathcal{N}', '𝓝'),
+    ('\\mathcal{O}', '𝓞'),
+    ('\\mathcal{P}', '𝓟'),
+    ('\\mathcal{Q}', '𝓠'),
+    ('\\mathcal{R}', '𝓡'),
+    ('\\mathcal{S}', '𝓢'),
+    ('\\mathcal{T}', '𝓣'),
+    ('\\mathcal{U}', '𝓤'),
+    ('\\mathcal{V}', '𝓥'),
+    ('\\mathcal{W}', '𝓦'),
+    ('\\mathcal{X}', '𝓧'),
+    ('\\mathcal{Y}', '𝓨'),
+    ('\\mathcal{Z}', '𝓩'),
     ('\\mathfrak C', 'ℭ'),
     ('\\mathfrak H', 'ℌ'),
     ('\\mathfrak Z', 'ℨ'),
+    ('\\mathfrak{A}', '𝔄'),
+    ('\\mathfrak{a}', '𝔞'),
+    ('\\mathfrak{B}', '𝔅'),
+    ('\\mathfrak{b}', '𝔟'),
+    ('\\mathfrak{c}', '𝔠'),
+    ('\\mathfrak{D}', '𝔇'),
+    ('\\mathfrak{d}', '𝔡'),
+    ('\\mathfrak{E}', '𝔈'),
+    ('\\mathfrak{e}', '𝔢'),
+    ('\\mathfrak{F}', '𝔉'),
+    ('\\mathfrak{f}', '𝔣'),
+    ('\\mathfrak{G}', '𝔊'),
+    ('\\mathfrak{g}', '𝔤'),
+    ('\\mathfrak{h}', '𝔥'),
+    ('\\mathfrak{i}', '𝔦'),
+    ('\\mathfrak{J}', '𝔍'),
+    ('\\mathfrak{j}', '𝔧'),
+    ('\\mathfrak{K}', '𝔎'),
+    ('\\mathfrak{k}', '𝔨'),
+    ('\\mathfrak{L}', '𝔏'),
+    ('\\mathfrak{l}', '𝔩'),
+    ('\\mathfrak{M}', '𝔐'),
+    ('\\mathfrak{m}', '𝔪'),
+    ('\\mathfrak{N}', '𝔑'),
+    ('\\mathfrak{n}', '𝔫'),
+    ('\\mathfrak{O}', '𝔒'),
+    ('\\mathfrak{o}', '𝔬'),
+    ('\\mathfrak{P}', '𝔓'),
+    ('\\mathfrak{p}', '𝔭'),
+    ('\\mathfrak{Q}', '𝔔'),
+    ('\\mathfrak{q}', '𝔮'),
+    ('\\mathfrak{r}', '𝔯'),
+    ('\\mathfrak{S}', '𝔖'),
+    ('\\mathfrak{s}', '𝔰'),
+    ('\\mathfrak{T}', '𝔗'),
+    ('\\mathfrak{t}', '𝔱'),
+    ('\\mathfrak{U}', '𝔘'),
+    ('\\mathfrak{u}', '𝔲'),
+    ('\\mathfrak{V}', '𝔙'),
+    ('\\mathfrak{v}', '𝔳'),
+    ('\\mathfrak{W}', '𝔚'),
+    ('\\mathfrak{w}', '𝔴'),
+    ('\\mathfrak{X}', '𝔛'),
+    ('\\mathfrak{x}', '𝔵'),
+    ('\\mathfrak{Y}', '𝔜'),
+    ('\\mathfrak{y}', '𝔶'),
+    ('\\mathfrak{z}', '𝔷'),
+    ('\\mathit{A}', '𝐴'),
+    ('\\mathit{a}', '𝑎'),
+    ('\\mathit{B}', '𝐵'),
+    ('\\mathit{b}', '𝑏'),
+    ('\\mathit{C}', '𝐶'),
+    ('\\mathit{c}', '𝑐'),
+    ('\\mathit{D}', '𝐷'),
+    ('\\mathit{d}', '𝑑'),
+    ('\\mathit{E}', '𝐸'),
+    ('\\mathit{e}', '𝑒'),
+    ('\\mathit{F}', '𝐹'),
+    ('\\mathit{f}', '𝑓'),
+    ('\\mathit{G}', '𝐺'),
+    ('\\mathit{g}', '𝑔'),
+    ('\\mathit{H}', '𝐻'),
+    ('\\mathit{h}', '𝘩'),
+    ('\\mathit{I}', '𝐼'),
+    ('\\mathit{i}', '𝑖'),
+    ('\\mathit{J}', '𝐽'),
+    ('\\mathit{j}', '𝑗'),
+    ('\\mathit{K}', '𝐾'),
+    ('\\mathit{k}', '𝑘'),
+    ('\\mathit{L}', '𝐿'),
+    ('\\mathit{l}', '𝑙'),
+    ('\\mathit{M}', '𝑀'),
+    ('\\mathit{m}', '𝑚'),
+    ('\\mathit{N}', '𝑁'),
+    ('\\mathit{n}', '𝑛'),
+    ('\\mathit{O}', '𝑂'),
+    ('\\mathit{o}', '𝑜'),
+    ('\\mathit{P}', '𝑃'),
+    ('\\mathit{p}', '𝑝'),
+    ('\\mathit{Q}', '𝑄'),
+    ('\\mathit{q}', '𝑞'),
+    ('\\mathit{R}', '𝑅'),
+    ('\\mathit{r}', '𝑟'),
+    ('\\mathit{S}', '𝑆'),
+    ('\\mathit{s}', '𝑠'),
+    ('\\mathit{T}', '𝑇'),
+    ('\\mathit{t}', '𝑡'),
+    ('\\mathit{U}', '𝑈'),
+    ('\\mathit{u}', '𝑢'),
+    ('\\mathit{V}', '𝑉'),
+    ('\\mathit{v}', '𝑣'),
+    ('\\mathit{W}', '𝑊'),
+    ('\\mathit{w}', '𝑤'),
+    ('\\mathit{X}', '𝑋'),
+    ('\\mathit{x}', '𝑥'),
+    ('\\mathit{Y}', '𝑌'),
+    ('\\mathit{y}', '𝑦'),
+    ('\\mathit{Z}', '𝑍'),
+    ('\\mathit{z}', '𝑧'),
     ('\\mathring{\\mathrm A}', 'Å'),
     ('\\mathrm K', 'K'),
     ('\\mathrm{d}', 'ⅆ'),
@@ -408,6 +598,26 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\mathrsfs H', 'ℋ'),
     ('\\mathrsfs I', 'ℐ'),
     ('\\mathrsfs L', 'ℒ'),
+    ('\\mathscr{A}', '𝒜'),
+    ('\\mathscr{C}', '𝒞'),
+    ('\\mathscr{D}', '𝒟'),
+    ('\\mathscr{G}', '𝒢'),
+    ('\\mathscr{J}', '𝒥'),
+    ('\\mathscr{K}', '𝒦'),
+    ('\\mathscr{M}', 'ℳ'),
+    ('\\mathscr{N}', '𝒩'),
+    ('\\mathscr{O}', '𝒪'),
+    ('\\mathscr{P}', '𝒫'),
+    ('\\mathscr{Q}', '𝒬'),
+    ('\\mathscr{R}', 'ℛ'),
+    ('\\mathscr{S}', '𝒮'),
+    ('\\mathscr{T}', '𝒯'),
+    ('\\mathscr{U}', '𝒰'),
+    ('\\mathscr{V}', '𝒱'),
+    ('\\mathscr{W}', '𝒲'),
+    ('\\mathscr{X}', '𝒳'),
+    ('\\mathscr{Y}', '𝒴'),
+    ('\\mathscr{Z}', '𝒵'),
     ('\\measuredangle', '∡'),
     ('\\mho', '℧'),
     ('\\mid', '∣'),
@@ -435,6 +645,7 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\not\\approx', '≉'),
     ('\\not\\asymp', '≭'),
     ('\\not\\equiv', '≢'),
+    ('\\not\\exists', '∄'),
     ('\\not\\gtrless', '≹'),
     ('\\not\\gtrsim', '≵'),
     ('\\not\\lessgtr', '≸'),
@@ -491,6 +702,7 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\pounds', '£'),
     ('\\prec', '≺'),
     ('\\preccurlyeq', '≼'),
+    ('\\preceq', '⪯'),
     ('\\precnsim', '⋨'),
     ('\\precsim', '≾'),
     ('\\prime', '′'),
@@ -531,6 +743,7 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\sampi', 'ϡ'),
     ('\\searrow', '↘'),
     ('\\second', '″'),
+    ('\\setminus', '⧵'),
     ('\\sharp', '♯'),
     ('\\Sigma', 'Σ'),
     ('\\sigma', 'σ'),
@@ -570,6 +783,7 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\subsetneq', '⊊'),
     ('\\succ', '≻'),
     ('\\succccurlyeq', '≽'),
+    ('\\succeq', '⪰'),
     ('\\succnsim', '⋩'),
     ('\\succsim', '≿'),
     ('\\sum', '∑'),
@@ -621,6 +835,7 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\triangleright', '⊳'),
     ('\\twoheadleftarrow', '↞'),
     ('\\twoheadrightarrow', '↠'),
+    ('\\underline{\\phantom{x}}', '̲'),
     ('\\unlhd', '⊴'),
     ('\\unrhd', '⊵'),
     ('\\uparrow', '↑'),
@@ -637,7 +852,11 @@ REPLACE_TEX_COMMANDS_LIBRARY: List[Tuple[str, str]] = [
     ('\\varepsilon', 'ε'),
     ('\\varkappa', 'ϰ'),
     ('\\varnothing', '∅'),
+    ('\\varphi', '𝜑'),
+    ('\\varpi', '𝜛'),
+    ('\\varrho', '𝜚'),
     ('\\varsigma', 'ς'),
+    ('\\vartheta', '𝜗'),
     ('\\vdash', '⊢'),
     ('\\Vdash', '⊩'),
     ('\\VDash', '⊫'),
